@@ -1,14 +1,37 @@
+//=========================================================
+//  MusE
+//  Linux Music Editor
+//  $Id: ./muse/shortcuts.h $
 //
-// C++ Interface: shortcuts
-//
-// Description:
-// Datastructures and declaration of shortcuts used in the application
+//  Copyright (C) 1999-2011 by Werner Schweer and others
 //
 // Author: Mathias Lundgren <lunar_shuttle@users.sourceforge.net>, (C) 2003
 //
 // Copyright: Mathias Lundgren (lunar_shuttle@users.sourceforge.net) (C) 2003
 //
 //
+//  This program is free software; you can redistribute it and/or
+//  modify it under the terms of the GNU General Public License
+//  as published by the Free Software Foundation; version 2 of
+//  the License, or (at your option) any later version.
+//
+//  This program is distributed in the hope that it will be useful,
+//  but WITHOUT ANY WARRANTY; without even the implied warranty of
+//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+//  GNU General Public License for more details.
+//
+//  You should have received a copy of the GNU General Public License
+//  along with this program; if not, write to the Free Software
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+//
+//=========================================================
+//
+// C++ Interface: shortcuts
+//
+// Description:
+// Datastructures and declaration of shortcuts used in the application
+//
+
 #ifndef __SHORTCUTS_H__
 #define __SHORTCUTS_H__
 
@@ -22,7 +45,7 @@
 #define DEDIT_SHRT       2  // Drumedit shortcut
 #define LEDIT_SHRT       4  // Listedit shortcut
 #define SCORE_SHRT       8  // Score shortcut
-#define ARRANG_SHRT     16  // Arrenger shortcut
+#define ARRANG_SHRT     16  // Arranger shortcut
 #define TRANSP_SHRT     32  // Transport shortcut
 #define WAVE_SHRT       64  // Waveedit shortcut
 #define GLOBAL_SHRT    128  // Global shortcuts
@@ -31,7 +54,9 @@
 #define ALL_SHRT      1023  // All shortcuts
 #define INVIS_SHRT    1024  // Shortcuts not shown in the config-dialog. Hard-coded. To avoid conflicts
 
-#define SHRT_NUM_OF_CATEGORIES   7 //Number of shortcut categories
+#define SHRT_NUM_OF_CATEGORIES   9 //Number of shortcut categories
+
+namespace MusEGui {
 
 struct shortcut
       {
@@ -39,6 +64,7 @@ struct shortcut
       const char* descr;
       const char* xml; //xml-tag for config-file
       int type;
+      shortcut() : key(0),  descr(NULL), xml(NULL), type(0) { }
       };
 
 struct shortcut_cg
@@ -63,6 +89,7 @@ enum {
       SHRT_TOGGLE_METRO, // C
       SHRT_START_REC, // *(keypad)
       SHRT_REC_CLEAR, // *(keypad)
+      SHRT_FULLSCREEN,
 
       //Main + Drumeditor
       SHRT_NEW, //Ctrl+N
@@ -73,8 +100,13 @@ enum {
       SHRT_UNDO,  //Ctrl+Z
       SHRT_REDO,  //Ctrl+Y
       SHRT_COPY,  //Ctrl+C
+      SHRT_COPY_RANGE, //Ctrl+Shift+C
       SHRT_CUT,   //Ctrl+X
       SHRT_PASTE, //Ctrl+V
+      SHRT_PASTE_CLONE, //CTRL+Shift+V
+      SHRT_PASTE_TO_TRACK, //CTRL+Key_B
+      SHRT_PASTE_CLONE_TO_TRACK, //CTRL+SHIFT+Key_B
+      SHRT_PASTE_DIALOG, //Ctrl+G
       SHRT_DELETE,//Delete
 
 
@@ -103,7 +135,6 @@ enum {
       SHRT_GLOBAL_CUT, //Default: undefined
       SHRT_GLOBAL_INSERT, //Default: undefined
       SHRT_GLOBAL_SPLIT, //Default: undefined
-      SHRT_COPY_RANGE, //Default: undefined
       SHRT_CUT_EVENTS, //Default: undefined
 
       SHRT_OPEN_TRANSPORT, //F11
@@ -118,7 +149,7 @@ enum {
       SHRT_FOLLOW_CONTINUOUS, //Default: undefined
 
       SHRT_GLOBAL_CONFIG, //Default: undefined
-      SHRT_CONFIG_SHORTCUTS, //Default: undefined
+      SHRT_CONFIG_SHORTCUTS, //Default: Ctrl+K
       SHRT_CONFIG_METRONOME, //Default: undefined
       SHRT_CONFIG_MIDISYNC, //Default: undefined
       SHRT_MIDI_FILE_CONFIG, //Default: undefined
@@ -147,6 +178,7 @@ enum {
 
       SHRT_ADD_MIDI_TRACK, //Default: Ctrl+J
       SHRT_ADD_DRUM_TRACK, //Default: undefined
+      SHRT_ADD_NEW_STYLE_DRUM_TRACK, //Default: undefined
       SHRT_ADD_WAVE_TRACK, //Default: undefined
       SHRT_ADD_AUDIO_OUTPUT, //Default: undefined
       SHRT_ADD_AUDIO_GROUP, //Default: undefined
@@ -164,15 +196,13 @@ enum {
       SHRT_SEL_BELOW, //Down
       SHRT_SEL_BELOW_ADD, //move down and add to selection
 
-      /*
-      SHRT_INSERT, //Ctrl+Shift+I   - insert parts instead of pasting
       SHRT_INSERTMEAS, //Ctrl+Shift+M - insert measures
-      */
+      
       //Arranger tracks
       SHRT_SEL_TRACK_BELOW,
       SHRT_SEL_TRACK_ABOVE,
 
-      //To be in arranger, pianoroll & drumeditor
+      //To be in arranger, pianoroll & drumeditor. p4.0.10 now globally handled, too.
       SHRT_SELECT_ALL, //Ctrl+A
       SHRT_SELECT_NONE, //Ctrl+Shift+A
       SHRT_SELECT_INVERT, //Ctrl+I
@@ -188,17 +218,51 @@ enum {
       SHRT_DEC_PITCH,
       SHRT_INC_POS,
       SHRT_DEC_POS,
+      
+      SHRT_POS_INC_NOSNAP,
+      SHRT_POS_DEC_NOSNAP,
+      
+      /*
+      SHRT_POS_INC_BAR,   
+      SHRT_POS_DEC_BAR,     
+      SHRT_POS_INC_BAR_NOSNAP, 
+      SHRT_POS_DEC_BAR_NOSNAP, 
+      
+      SHRT_POS_INC_BEAT,    
+      SHRT_POS_DEC_BEAT,    
+      SHRT_POS_INC_BEAT_NOSNAP,
+      SHRT_POS_DEC_BEAT_NOSNAP,
+      
+      SHRT_POS_INC_TICK,    
+      SHRT_POS_DEC_TICK,    
+      SHRT_POS_INC_TICK_NOSNAP,
+      SHRT_POS_DEC_TICK_NOSNAP,
+      
+      SHRT_POS_INC_MINUTE,     
+      SHRT_POS_DEC_MINUTE,     
+      SHRT_POS_INC_MINUTE_NOSNAP,
+      SHRT_POS_DEC_MINUTE_NOSNAP,
+      
+      SHRT_POS_INC_SECOND,     
+      SHRT_POS_DEC_SECOND,     
+      SHRT_POS_INC_SECOND_NOSNAP,
+      SHRT_POS_DEC_SECOND_NOSNAP,
+      
+      SHRT_POS_INC_FRAME,      
+      SHRT_POS_DEC_FRAME,      
+      */
+      
       SHRT_LOCATORS_TO_SELECTION, //Alt+P, currently in arranger & pianoroll
       SHRT_INSERT_AT_LOCATION, //Shift+CrsrRight
       SHRT_INCREASE_LEN,
       SHRT_DECREASE_LEN,
 
-      SHRT_TOOL_1,//Shift+1 Pointer
-      SHRT_TOOL_2,//Shift+2 Pen
-      SHRT_TOOL_3,//Shift+3 Rubber
-      SHRT_TOOL_4,//Shift+4
-      SHRT_TOOL_5,//Shift+5
-      SHRT_TOOL_6,//Shift+6
+      //SHRT_TOOL_1,//Shift+1 Pointer
+      //SHRT_TOOL_2,//Shift+2 Pen
+      //SHRT_TOOL_3,//Shift+3 Rubber
+      //SHRT_TOOL_4,//Shift+4
+      //SHRT_TOOL_5,//Shift+5
+      //SHRT_TOOL_6,//Shift+6
       SHRT_TRANSPOSE, //Default: undefined
 
       //Shortcuts to be in pianoroll & drumeditor
@@ -209,11 +273,6 @@ enum {
       SHRT_SCROLL_RIGHT, // l
       SHRT_FIXED_LEN, //Alt+L, currently only drumeditor
       SHRT_QUANTIZE, //q
-      SHRT_OVER_QUANTIZE, //Default: undefined
-      SHRT_ON_QUANTIZE, //Default: undefined
-      SHRT_ONOFF_QUANTIZE, //Default: undefined
-      SHRT_ITERATIVE_QUANTIZE, //Default: undefined
-      SHRT_CONFIG_QUANT, //Default: Ctrl+Alt+Q
       SHRT_MODIFY_GATE_TIME, //Default: undefined
       SHRT_MODIFY_VELOCITY,
       SHRT_CRESCENDO,
@@ -245,10 +304,26 @@ enum {
       SHRT_TOOL_POINTER,  //
       SHRT_TOOL_PENCIL,
       SHRT_TOOL_RUBBER,
-
+      SHRT_TOOL_PAN,
+      SHRT_TOOL_ZOOM,
+      
       // pianoroll and drum editor
       SHRT_TOOL_LINEDRAW,
 
+      // drum editor
+      SHRT_TOOL_CURSOR,
+      SHRT_ADDNOTE_1,
+      SHRT_ADDNOTE_2,
+      SHRT_ADDNOTE_3,
+      SHRT_ADDNOTE_4,
+      SHRT_CURSOR_STEP_UP,
+      SHRT_CURSOR_STEP_DOWN,
+      SHRT_INSTRUMENT_STEP_DOWN,
+      SHRT_INSTRUMENT_STEP_UP,
+
+      // wave editor
+      SHRT_TOOL_RANGE,
+      
       // arranger
       SHRT_TOOL_SCISSORS,
       SHRT_TOOL_GLUE,
@@ -268,7 +343,8 @@ enum {
       SHRT_LM_INS_SIG,   // Ctrl+R
       SHRT_LM_EDIT_BEAT, // Ctrl+Shift+E
       SHRT_LM_EDIT_VALUE,// Ctrl+E
-      
+      SHRT_LM_INS_KEY,   // Ctrl+K
+
       // Marker view
       SHRT_NEXT_MARKER,
       SHRT_PREV_MARKER,
@@ -279,7 +355,10 @@ enum {
 
 extern ShortCut shortcuts[SHRT_NUM_OF_ELEMENTS]; //size of last entry
 extern void initShortCuts();
-extern void writeShortCuts(int level, Xml& xml);
-extern void readShortCuts (Xml& xml);
+extern void writeShortCuts(int level, MusECore::Xml& xml);
+extern void readShortCuts (MusECore::Xml& xml);
 extern const shortcut_cg shortcut_category[SHRT_NUM_OF_CATEGORIES];
+
+} // namespace MusEGui
+
 #endif
