@@ -3,13 +3,31 @@
 //  Linux Music Editor
 //    $Id: dentry.cpp,v 1.1.1.1.2.3 2008/08/18 00:15:26 terminator356 Exp $
 //  (C) Copyright 1999 Werner Schweer (ws@seh.de)
+//
+//  This program is free software; you can redistribute it and/or
+//  modify it under the terms of the GNU General Public License
+//  as published by the Free Software Foundation; version 2 of
+//  the License, or (at your option) any later version.
+//
+//  This program is distributed in the hope that it will be useful,
+//  but WITHOUT ANY WARRANTY; without even the implied warranty of
+//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+//  GNU General Public License for more details.
+//
+//  You should have received a copy of the GNU General Public License
+//  along with this program; if not, write to the Free Software
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+//
 //=========================================================
 
-#include "dentry.h"
 #include <stdio.h>
-#include <qtimer.h>
-#include <qcursor.h>
+
+#include <QContextMenuEvent>
+#include <QTimer>
+
+#include "dentry.h"
 #include "globals.h"
+#include "gconfig.h"
 
 #define TIMER1    400
 #define TIMER2    200
@@ -18,13 +36,16 @@
 #define TIMEC2    20
 #define TIMER4    50
 
+namespace MusEGui {
+
 //---------------------------------------------------------
 //   Dentry
 //    lineedit double values
 //---------------------------------------------------------
 
-Dentry::Dentry(QWidget* parent, const char* name) : QLineEdit(parent, name)
+Dentry::Dentry(QWidget* parent, const char* name) : QLineEdit(parent)
       {
+      setObjectName(name);
       _slider = 0;      
       _id = -1;
       drawFrame = false;
@@ -33,7 +54,7 @@ Dentry::Dentry(QWidget* parent, const char* name) : QLineEdit(parent, name)
       connect(timer, SIGNAL(timeout()), SLOT(repeat()));
       val = 0.01;
       connect(this, SIGNAL(returnPressed()), SLOT(endEdit()));
-      setCursor(QCursor(arrowCursor));
+      setCursor(QCursor(Qt::ArrowCursor));
       evx = 1.0;
       }
 
@@ -63,7 +84,7 @@ void Dentry::setFrame(bool flag)
 
 void Dentry::endEdit()
       {
-      if (edited()) {
+      if (isModified()) {
             if (setSValue(text())) {
                   setString(val);
                   return;
@@ -151,15 +172,17 @@ void Dentry::repeat()
             }
 
       switch (button) {
-            case QMouseEvent::LeftButton:
-                  return;
-            case QMouseEvent::MidButton:
+            case Qt::LeftButton:
+                  if (!MusEGlobal::config.leftMouseButtonCanDecrease)
+                    return;
+                  // else fall through
+            case Qt::MidButton:
                   if(_slider)
                     _slider->stepPages(-1);
                   else  
                     decValue(evx);
                   break;
-            case QMouseEvent::RightButton:
+            case Qt::RightButton:
                   if(_slider)
                     _slider->stepPages(1);
                   else  
@@ -176,7 +199,7 @@ void Dentry::repeat()
 
 void Dentry::mouseReleaseEvent(QMouseEvent*)
       {
-      button = QMouseEvent::NoButton;
+      button = Qt::NoButton;
       timer->stop();
       }
 
@@ -187,11 +210,11 @@ void Dentry::mouseReleaseEvent(QMouseEvent*)
 void Dentry::mouseMoveEvent(QMouseEvent*)
       {
       switch (button) {
-            case QMouseEvent::LeftButton:
+            case Qt::LeftButton:
                   break;
-            case QMouseEvent::MidButton:
+            case Qt::MidButton:
                   break;
-            case QMouseEvent::RightButton:
+            case Qt::RightButton:
                   break;
             default:
                   break;
@@ -204,7 +227,7 @@ void Dentry::mouseMoveEvent(QMouseEvent*)
 
 void Dentry::mouseDoubleClickEvent(QMouseEvent* event)
       {
-      if (event->button() != QMouseEvent::LeftButton) {
+      if (event->button() != Qt::LeftButton) {
             mousePressEvent(event);
             return;
             }
@@ -212,6 +235,8 @@ void Dentry::mouseDoubleClickEvent(QMouseEvent* event)
       QLineEdit::setFrame(true);
       update();
       emit doubleClicked(_id);
+      if(event->modifiers() & Qt::ControlModifier)
+        emit ctrlDoubleClicked(_id);
       }
 
 //---------------------------------------------------------
@@ -237,3 +262,4 @@ void Dentry::setValue(double v)
       val = v;
       }
 
+} // namespace MusEGui
